import { Box } from "@chakra-ui/react";
import { getPermissions, getPermissionsById } from "@/app/lib/role/action";
import RoleForm from "../../components/form";
import { getProjects } from "@/app/lib/projects/action";
import { ProjectDropdownInterface, ProjectOptionInterface } from "@/types/project";

interface Permission {
  id: number;
  name: string;
}

interface InitialPermissionsData {
  id: number;
  name: string;
  projects: ProjectDropdownInterface[];
  permissions: Permission[];
}

const Edit = async ({ params }: { params: { id: number } }) => {
  const searchParams = { pagination: false };
  const [projects, permissions] = await Promise.all([getProjects(searchParams), getPermissions()]);
  const initialPermissionsData: InitialPermissionsData =
    await getPermissionsById(params.id);
  const initialPermissions: string[] = initialPermissionsData.permissions.map(
    (perm) => perm.name
  );

  const initialProjects: ProjectOptionInterface[] =
    initialPermissionsData?.projects?.map((item) => {
      return { value: item?.id, label: item?.name };
    }) || [];
  
  return (
    <Box pt={{ base: "130px", md: "80px", xl: "80px" }} mb="20px">
      {permissions && initialPermissions && (
        <RoleForm
          modules={permissions}
          initialPermissions={initialPermissions}
          currentProjects={initialProjects}
          roleName={initialPermissionsData.name}
          isEdit={true}
          projects={projects.data}
        />
      )}
    </Box>
  );
};

export default Edit;
